summary | shortlog | log | commit | commitdiff | tree
raw | patch | inline | side by side (parent: b3f5602)
raw | patch | inline | side by side (parent: b3f5602)
author | buliabyak <buliabyak@users.sourceforge.net> | |
Sun, 19 Mar 2006 23:30:45 +0000 (23:30 +0000) | ||
committer | buliabyak <buliabyak@users.sourceforge.net> | |
Sun, 19 Mar 2006 23:30:45 +0000 (23:30 +0000) |
src/sp-item.cpp | patch | blob | history |
diff --git a/src/sp-item.cpp b/src/sp-item.cpp
index 4dbdb127d00a99e456ec5ad5ca403e8b6408d59a..6aae4609e6908add2bf5aa81780a1e93be2104ae 100644 (file)
--- a/src/sp-item.cpp
+++ b/src/sp-item.cpp
@@ -1147,10 +1147,11 @@ sp_item_write_transform(SPItem *item, Inkscape::XML::Node *repr, NR::Matrix cons
sp_item_adjust_paint_recursive (item, NR::identity(), NR::identity(), false);
}
// run the object's set_transform if transforms are stored optimized
gint preserve = prefs_get_int_attribute("options.preservetransform", "value", 0);
NR::Matrix transform_attr (transform);
- if (((SPItemClass *) G_OBJECT_GET_CLASS(item))->set_transform && !preserve) {
+ if (((SPItemClass *) G_OBJECT_GET_CLASS(item))->set_transform
+ && !preserve && !item->clip_ref->getObject() && !item->mask_ref->getObject()) {
transform_attr = ((SPItemClass *) G_OBJECT_GET_CLASS(item))->set_transform(item, transform);
}
sp_item_set_item_transform(item, transform_attr);
@@ -1147,10 +1147,11 @@ sp_item_write_transform(SPItem *item, Inkscape::XML::Node *repr, NR::Matrix cons
sp_item_adjust_paint_recursive (item, NR::identity(), NR::identity(), false);
}
- // run the object's set_transform if transforms are stored optimized
+ // run the object's set_transform if transforms are stored optimized and there's no clippath or mask
gint preserve = prefs_get_int_attribute("options.preservetransform", "value", 0);
NR::Matrix transform_attr (transform);